@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/extensions/newsblog/content/feed-subscriptions.js"
+//@line 38 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/extensions/newsblog/content/feed-subscriptions.js"
 
 const MSG_FOLDER_FLAG_TRASH = 0x0100;
 const IPS = Components.interfaces.nsIPromptService;
@@ -819,7 +819,7 @@ var gFeedSubscriptionsWindow = {
       else if(rv)
       {
         //debug("opml:\n"+serial.serializeToString(opmlDoc)+"\n");
-        var file = new LocalFile(rv.file, MODE_WRONLY | MODE_CREATE);
+        var file = new LocalFile(rv.file, MODE_WRONLY | MODE_CREATE | MODE_TRUNCATE);
         serial.serializeToStream(opmlDoc,file.outputStream,'utf-8');
         file.close();
       }
