@@ -1,4 +1,4 @@
-//@line 41 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/viewpasswords.js"
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/viewpasswords.js"
 
 /*** =================== INITIALISATION CODE =================== ***/
 
@@ -209,9 +209,21 @@ function DeleteSignon() {
 }
 
 function DeleteAllSignons() {
+  var prompter = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
+                           .getService(Components.interfaces.nsIPromptService);
+
+  // Confirm the user wants to remove all passwords
+  var dummy = { value: false };
+  if (prompter.confirmEx(window,
+                         kSignonBundle.getString("removeAllPasswordsTitle"),
+                         kSignonBundle.getString("removeAllPasswordsPrompt"),
+                         prompter.STD_YES_NO_BUTTONS + prompter.BUTTON_POS_1_DEFAULT,
+                         null, null, null, null, dummy) == 1) // 1 == "No" button
+    return;
+    
   DeleteAllFromTree(signonsTree, signonsTreeView,
-                        signons, deletedSignons,
-                        "removeSignon", "removeAllSignons");
+                    signons, deletedSignons,
+                    "removeSignon", "removeAllSignons");
   FinalizeSignonDeletions();
 }
 
